/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description:
ExampleInetProtUtil is a sample code for understanding the applicability of InetProtUtil. 
It is intended as an example and introduction to the INETPROTUTIL API's.
Users should have a brief understanding of URIs and the different concepts
associated with it, like, URLs and URI components. 
*/


// System includes
//
#include <uri8.h>
#include <delimitedparser8.h>
#include <inetprottextutils.h>
#include <escapeutils.h>
#include <e32cons.h>


////////////////////////////////////////////////////////
//				CExampleInetProtUtil			      //
////////////////////////////////////////////////////////

class CExampleInetProtUtil : public CBase
{	
public :

	CExampleInetProtUtil();
	
	virtual ~CExampleInetProtUtil();
	
	void ConstructL();
	
	static void NewL();
	
	//Create an URI
	void CreateUriL();
	
	//Modify URI components
	void ModifyUriComponentsL();
	
	//Resolve
	void ResolveUriL();
	
	//Parse the URI
	void ParseUriL();
	
	//Validate URI components
	void ValidateUriComponentsL();
	
	//Extract URI components
	void ExtractUriComponentsL();
	
	//Retrieve Filename from a given Uri
	void RetrieveFileNameL();
	
	//Add and Trim delimiters
	void ModifyDelimiterL();
	
	//Text Utilities
	void WhiteSpaceRemover();
	
	//Escape encode and decode
	void EscapeEncodeDecodeL();
	
private:
	CConsoleBase* iConsole;
	
};
	
	
	
////////////////////////////////////////////////////////
//			 CExampleDelimiterModifier	     	      //
////////////////////////////////////////////////////////
	
	
class CExampleDelimiterModifier : public TDelimitedParserBase8 //, public CDelimitedDataBase8
{
public:	// Methods

	inline TBool CheckFrontDelimiter() const;

	inline TBool CheckBackDelimiter() const;

    CExampleDelimiterModifier();

	inline void Parse(const TDesC8& aData);

	inline void SetDelimiter(TChar );
	
};

void CExampleDelimiterModifier::SetDelimiter(TChar aChar)
{
	TDelimitedParserBase8::SetDelimiter(aChar);
}
	
void CExampleDelimiterModifier::Parse(const TDesC8& aData)
{
	TDelimitedParserBase8::Parse(aData);
}
	
CExampleDelimiterModifier::CExampleDelimiterModifier()
{
	
}
	
TBool CExampleDelimiterModifier::CheckFrontDelimiter() const
{
		TBool frontDelimiter = FrontDelimiter();
		return frontDelimiter;
}

TBool CExampleDelimiterModifier::CheckBackDelimiter() const
{
		TBool backDelimiter = BackDelimiter();
		return backDelimiter;
}
